move libiu to osmo-iuh/libosmo-ranap

Remove libiu here, use the functions from libosmo-ranap instead, by applying
the ranap_ / RANAP_ prefix.

Corresponding change-id in osmo-iuh.git is I6a3f7ad15be03fb94689b4af6ccfa828c25f45c0

To be able to run the msc_vlr tests for RAN_UTRAN_IU without Iu client headers
available, add iu_dummy.h, containing mere function signatures that match
iu_dummy.c and a mostly empty struct ranap_ue_conn_ctx.

Make sure we can build with and without --enable-iu: include osmo-iuh headers
only with --enable-iu.

Change-Id: Ib8c4fcdb4766c5e575618b95ce16dce51063206b
diff --git a/src/libmsc/iucs.c b/src/libmsc/iucs.c
index be026c8..04b9ece 100644
--- a/src/libmsc/iucs.c
+++ b/src/libmsc/iucs.c
@@ -25,17 +25,17 @@
 #include <inttypes.h>
 
 #include <osmocom/core/logging.h>
+#include <osmocom/ranap/iu_client.h>
 #include <openbsc/debug.h>
 
 #include <openbsc/gsm_data.h>
-#include <openbsc/iu.h>
 #include <openbsc/gsm_subscriber.h>
 #include <openbsc/osmo_msc.h>
 #include <openbsc/vlr.h>
 
 /* For A-interface see libbsc/bsc_api.c subscr_con_allocate() */
 static struct gsm_subscriber_connection *subscr_conn_allocate_iu(struct gsm_network *network,
-								 struct ue_conn_ctx *ue,
+								 struct ranap_ue_conn_ctx *ue,
 								 uint16_t lac)
 {
 	struct gsm_subscriber_connection *conn;
@@ -57,7 +57,7 @@
 	return conn;
 }
 
-static int same_ue_conn(struct ue_conn_ctx *a, struct ue_conn_ctx *b)
+static int same_ue_conn(struct ranap_ue_conn_ctx *a, struct ranap_ue_conn_ctx *b)
 {
 	if (a == b)
 		return 1;
@@ -103,7 +103,7 @@
  * connection IDs, or return NULL if not found. */
 struct gsm_subscriber_connection *subscr_conn_lookup_iu(
 						struct gsm_network *network,
-						struct ue_conn_ctx *ue)
+						struct ranap_ue_conn_ctx *ue)
 {
 	struct gsm_subscriber_connection *conn;
 
@@ -126,7 +126,7 @@
 }
 
 /* Receive MM/CC/... message from IuCS (SCCP user SAP).
  * msg->dst must reference a struct ue_conn_ctx, which identifies the peer that
  * sent the msg.
  *
  * For A-interface see libbsc/bsc_api.c gsm0408_rcvmsg(). */
@@ -134,10 +134,10 @@
 			uint16_t *lac)
 {
 	int rc;
-	struct ue_conn_ctx *ue_ctx;
+	struct ranap_ue_conn_ctx *ue_ctx;
 	struct gsm_subscriber_connection *conn;
 
-	ue_ctx = (struct ue_conn_ctx*)msg->dst;
+	ue_ctx = (struct ranap_ue_conn_ctx*)msg->dst;
 
 	/* TODO: are there message types that could allow us to skip this
 	 * search? */
@@ -126,7 +126,7 @@
 
 /* Receive MM/CC/... message from IuCS (SCCP user SAP).
- * msg->dst must reference a struct ue_conn_ctx, which identifies the peer that
+ * msg->dst must reference a struct ranap_ue_conn_ctx, which identifies the peer that
  * sent the msg.
  *